Diofant
=======

.. image:: https://github.com/diofant/diofant/workflows/test/badge.svg
   :target: https://github.com/diofant/diofant/actions?workflow=test

.. image:: https://codecov.io/gh/diofant/diofant/branch/master/graph/badge.svg
    :target: https://codecov.io/gh/diofant/diofant

.. image:: https://readthedocs.org/projects/diofant/badge/?style=flat
    :target: https://diofant.readthedocs.io/en/latest/

A `Python`_ library for symbolic mathematics.

For `installation instructions`_ and usage information,
see the `online documentation`_.

`New BSD License`_ covers all files in `this repository`_
unless stated otherwise.

.. _Python: https://www.python.org/
.. _online documentation: https://diofant.readthedocs.io/en/latest/
.. _installation instructions: https://diofant.readthedocs.io/en/latest/install.html#installation
.. _New BSD License: https://github.com/diofant/diofant/blob/master/LICENSE.rst
.. _this repository: https://github.com/diofant/diofant/
